$fn=100;

module caseTop()
{
  length=68;
  width=26;
  wallThickness=2.4;
  
  curveRadius=2.5;
  
  outputRadius=4.4;
  
  boltDistance=10.5;
  boltRadius=3.5;
  
  addendum=1.5;
  clearance=0.75;
  bigRadius=11;
  smallRadius=11/2;
  
  boxWidth=12;
  boxHeight=15;
  sensorHeight=6;
  
  sensorLocation=addendum+clearance+3*bigRadius;
  
  outputShaft=8/2;
  outputLocation=sensorLocation+smallRadius+bigRadius;
  
  headerWidth=14.75;
  headerDepth=12;
  headerThickness=2.5;
  
  bowlHeight=2;
  bowlAngle=30;
  bowlRadius=6;
  
  /*union()
  {
    sensorBox();
    translate([-13, -13, -1.0])
    {
      cube([26, 26, 1.0]);
    }
  }*/
  
  
  difference()
  {
    union()
    {
      difference()
      {
        union()
        { 
          translate([0, 0, -3*wallThickness]) baseShape(true);
          translate([0, 0, -2*wallThickness]) baseShape(false);
          translate([0, 0, -wallThickness]) cube([length, width, wallThickness]);
        }
        translate([wallThickness, wallThickness, -2*wallThickness])
        {
          cube([length-2*wallThickness, width-2*wallThickness, 2*wallThickness]);
        }
        translate([sensorLocation-boxWidth/2, 0, -2*wallThickness])
        {
          cube([boxWidth, wallThickness, 2*wallThickness]);//
        }
      }
      translate([sensorLocation, width/2, -2*wallThickness]) rotate([0, 0, 180])
      {
        rotate([0, 0, 180]) sensorBox();
      }
      
      translate([wallThickness, width-headerDepth, -2*wallThickness])
      {
        cube([headerWidth+wallThickness, headerDepth+wallThickness, headerThickness]);
      }
      translate([outputLocation, width/2, -2*wallThickness-0.001])
      {
        cylinder(r=bowlRadius, h=bowlHeight);
      }
      
    }
    
    translate([outputLocation, width/2, -3*wallThickness])
    {
      cylinder(r=outputShaft, h=wallThickness);
      translate([0, 0, wallThickness])
      {
        cylinder(r1=outputShaft, r2=outputShaft+bowlHeight*tan(bowlAngle), h=bowlHeight);
      }
    }
    
    translate([wallThickness, width+wallThickness-headerDepth, -2*wallThickness])
    {
      cube([headerWidth, headerDepth, 3*wallThickness]);
    }
  }
  
  module baseShape(endPiece)
  {
    offset_=2*(wallThickness-curveRadius);
    baseLength=length+offset_;
    baseWidth=width+offset_;
    barWidth=2*boltRadius+2*wallThickness+offset_;
    barLength=2*boltDistance+length+offset_;
    
    linear_extrude(height=wallThickness) difference()
    {
      union()
      {
        offset(r=-curveRadius) offset(2*curveRadius) union()
        {
          translate([-offset_/2, -offset_/2, 0]) square([baseLength, baseWidth]);
          if(endPiece)
          {
            translate([-boltDistance-offset_/2, (width-barWidth)/2, 0])
            {
              square([barLength, barWidth]);
            }
            translate([-boltDistance, width/2, 0]) circle(r=boltRadius+wallThickness+offset_/2);
            translate([length+boltDistance, width/2, 0]) circle(r=boltRadius+wallThickness+offset_/2);
          }
        }
      }
      translate([-boltDistance, width/2, 0]) circle(r=boltRadius);
      translate([length+boltDistance, width/2, 0]) circle(r=boltRadius);
    }
  }
  
  module sensorBox()
  {
    boxWall=0.8;
    outerWidth=boxWidth+2*boxWall;
    
    axleRadius=3;
    inputRadius=3.5;
    endstopGap=0.6;
    endstopWidth=6;
    endstopThickness=.8;
    endstopThickness2=2;
    
    flexGapDistance=1;
    
    union()
    {
      difference()
      {
        baseCube();
        
        translate([boxWidth/2, 0, sensorHeight]) axleSocket();
        rotate([0, 0, 90]) translate([boxWidth/2, 0, sensorHeight]) axleSocket();
        
        translate([-boxWidth/2, 0, sensorHeight]) inputSlot();
        rotate([0, 0, 90]) translate([-boxWidth/2, 0, sensorHeight]) inputSlot();
        
        //translate([0, 0, boxHeight-flexGapDistance]) flexGap();
        //rotate([0, 0, 90]) translate([0, 0, boxHeight-flexGapDistance]) flexGap();
      }
      
      rotate([0, 0, 180]) translate([boxWidth/2, 0, sensorHeight]) sensorHolder();
      rotate([0, 0, -90]) translate([boxWidth/2, 0, sensorHeight]) sensorHolder();
      
      translate([boxWidth/2+boxWall, 0, 0]) endStop();
      rotate([0, 0, 90]) translate([boxWidth/2+boxWall, 0, 0]) endStop();
    }
    
    
    
    
    module inputSlot()
    {
      translate([-3*boxWall/2, -inputRadius, -inputRadius])
      {
        cube([3*boxWall, 2*inputRadius, 2*inputRadius]);
      }
    }
    
    module baseCube()
    {
      difference()
      {
        translate([-outerWidth/2, -outerWidth/2, 0])
        {
          cube([outerWidth, outerWidth, boxHeight]);
        }
        translate([-boxWidth/2, -boxWidth/2, -0.05])
        {
          cube([boxWidth, boxWidth, boxHeight+0.1]);
        }
      }
    }
    
    module axleSocket()
    {
      baseAngle=45;
      x0=axleRadius/cos(baseAngle);
      x1=-axleRadius;
      y0=0;
      y1=(x0+axleRadius)*tan(90-baseAngle);
      points=[[x0, y0], [x1, y1], [x1, -y1]];
      tolerance=0.5;
      
      gapLength=9;
      gapWidth=3.6;
      
      barThickness=1.6;
      barPosition=2.4;
      
      rotate([180, 0, 0])
      {
        rotate([0, 90, 0])
        {
          translate([0, 0, -3*boxWall/2])
          {
            linear_extrude(height=3*boxWall)
            {
             difference()
              {
                union()
                {
                  intersection()
                  {
                    polygon(points=points, path=[0, 1, 2]);
                    translate([-axleRadius-tolerance, -gapLength/2, 0])//-axleRadius-tolerance, 0])
                    {
                      square([2*(axleRadius+tolerance), gapLength]);//2*(axleRadius+tolerance)]);
                    }
                  }
                  
                  translate([-gapWidth/2-barThickness/2-barPosition, -gapLength/2, 0])
                  {
                    square([gapWidth, gapLength]);
                  }
                }
                translate([-barThickness-barPosition, -gapLength/2, 0])
                {
                  square([barThickness, gapLength]);
                }
              }
            }
          }
        }
      }
    }
    
    module flexGap()
    {
      thickness=0.6;
      width=9;
      translate([-outerWidth/2, -width/2, -thickness])
      {
        cube([outerWidth, width, thickness]);
      }
    }
    
    module endStop()
    {
      heightDifference=1.5;
      translate([endstopGap, -endstopWidth/2, 0])
      {
        cube([endstopThickness, endstopWidth, sensorHeight-heightDifference]);
        
      }
      translate([endstopGap, -endstopThickness/2, 0])
      {
        cube([endstopThickness2, endstopThickness, sensorHeight-heightDifference]);
      }
    }
    
    module sensorHolder()
    {
      holderWall=0.8;
      outerRadius=3.75;
      sensorWidth=6.4;
      sensorLength=7.7;
      
      baseThickness=2.75;
      rotorThickness=1.25;
      totalThickness=baseThickness+rotorThickness;
      
      holderHeight=sensorHeight+outerRadius+holderWall;
      holderWidth=boxWidth;//12;//sensorWidth+2*holderWall;
      
      sideBlockHeight=8;
      sideBlockLength=3;
      cutoutWidth=8;
      plateDistance=0.75;
      
      topCurve=2;

      
      
      
      translate([totalThickness, 0, 0])
      {
        difference()
        {
          union()
          {
            intersection()
            {
              translate([-totalThickness, -holderWidth/2, -sensorHeight])
              {
                cube([totalThickness, holderWidth, holderHeight]);
              }
              translate([-totalThickness, topCurve-holderWidth/2, -sensorHeight])
              {
                minkowski()
                {
                  cube([totalThickness, holderWidth-2*topCurve, holderHeight-topCurve]);
                  
                  rotate([0, 90, 0])
                  {
                    cylinder(r=topCurve, h=totalThickness);
                  }
                }
              }
            }
            translate([0, -holderWidth/2, -sensorHeight])
            {
              cube([sideBlockLength, holderWidth, sideBlockHeight]);
            }
          }
          
          translate([plateDistance, 0, -sensorHeight]) plate();
          
          translate([0, -cutoutWidth/2, -sensorHeight])
          {
            cube([sideBlockLength, cutoutWidth, sideBlockHeight]);
          }
          
          rotate([0, -90, 0])
          {
            intersection()
            {
              translate([-sensorLength/2, -sensorWidth/2, -0.1])
              {
                cube([sensorLength, sensorWidth, totalThickness+0.2]);
              }
              union()
              {
                translate([0, 0, -0.1]) cylinder(r=outerRadius, h=baseThickness+0.1);
                translate([-sensorLength/2, -outerRadius, -0.1])
                {
                  cube([sensorLength/2, 2*outerRadius, baseThickness+0.1]);
                }
                
                cylinder(r=inputRadius, h=totalThickness+0.1);
                translate([-inputRadius, -inputRadius, 0]) cube([inputRadius, 2*inputRadius, totalThickness+0.1]);
              }
            }
          }
        }
      }
      
      module plate()
      {
        plateWidth=10.5;
        plateThickness=0.8;
        bumpLength=1;
        bumpWidth=0.4;
        bumpHeight=4;
        
        rotate([0, 0, 180])
        {
          translate([-plateThickness, 0, 0])
          {
            difference()
            {
              union()
              {
                translate([0, -plateWidth/2, 0])
                {
                  cube([plateThickness, plateWidth, sideBlockHeight]);
                }
                
                translate([plateThickness, -plateWidth/2, bumpHeight-bumpLength/2-plateThickness])
                {
                  bump(bumpWidth, plateWidth, bumpLength+2*plateThickness, 30);
                }
              }
              
              translate([0, -plateWidth/2, bumpHeight-bumpLength/2])
              {
                bump(bumpWidth, plateWidth, bumpLength, 60);
              }
            }
          }
        }
        
        module bump(depth, width, height, angle)
        {
          
          x0=0;
          x1=height*tan(angle)/2;
          y0=0;
          y1=height;
          y2=height/2;
          
          translate([0, width, 0])
          {
            rotate([90, 0, 0])
            {
              linear_extrude(height=width)
              {
                intersection()
                {
                  polygon(points=[[x0, y0], [x0, y1], [x1, y2]], path=[0, 1, 2]);
                  square([depth, height]);
                }
              }
            }
          }
        }
      }
      
    }
  }
  

}

caseTop();















