$fn=100;

module caseAssembled()
{
  length=68;
  width=26;
  height=53;
  
  wallThickness=2.399;
  
  smallRadius=5.5;
  bigRadius=11;
  addendum=1.5;
  clearance=0.75;
  
  motorBoltHeight=21;
  motorWidth=20.5;
  
  axleRadius=2.3;
  support0X=addendum+3*bigRadius+clearance;
  support0Z=34;
  support1X=support0X+bigRadius+smallRadius;
  support1Z=25;
  
  layerHeight=0.2;
   
  union()
  {
    difference()
    {
      mainBox();
      cube([length, width, height]);
      clampCutout(false);
      clampCutout(true);
    }
    translate([support0X, width/2, support0Z]) support(false);
    translate([support1X, width/2, support1Z]) support(true);
    motorClamp();
  }
  
  module mainBox()
  {
    curveRadius=2.5;
    offset_=2*(wallThickness-curveRadius);
    translate([-offset_/2, -offset_/2, 0]) linear_extrude(height=height) offset(r=curveRadius)
    {
      square([length+offset_, width+offset_]);
    }
  }
  
  module clampCutout(position)
  {
    if(position==false)
    {
      tolerance=0.6;
      offset_=(motorWidth+tolerance);
      
      translate([0, (width-offset_)/2, motorBoltHeight-offset_/2]) rotate([0, -90, 0])
      {
        cube([motorWidth+tolerance, motorWidth+tolerance, wallThickness]);
      }
    }
    else if(position==true)
    {
      tolerance=0.6;
      offset_=motorWidth+tolerance;
      supportThickness=2;
      
      translate([wallThickness+length, (width-offset_)/2, support1Z+supportThickness-offset_/2])
      {
        rotate([0, -90, 0])
        {
          cube([motorWidth+tolerance, motorWidth+tolerance, wallThickness]);
        }
      }
    }
  }
  
  module support(extend)
  {
    thickness=2;
    supportWidth=8;
    if(extend==true)
    {
      extension=3;
      difference()
      {
        translate([-(extension+supportWidth)/2, -width/2, 0]) cube([supportWidth+extension, width, thickness]);
        hull() 
        {
          translate([-extension/2, 0, layerHeight]) cylinder(r=axleRadius, h=thickness);
          translate([extension/2, 0, layerHeight]) cylinder(r=axleRadius, h=thickness);
        }
      }
    }
    
    else if(extend==false)
    {
      extension=0 ;
      difference()
      {
        translate([-(extension+supportWidth)/2, -width/2, 0]) cube([supportWidth+extension, width, thickness]);
        hull() 
        {
          translate([-extension/2, 0, layerHeight]) cylinder(r=axleRadius, h=thickness);
          translate([extension/2, 0, layerHeight]) cylinder(r=axleRadius, h=thickness);
        }
      }
    }
    
  }
  
  module motorClamp()
  {
    lockPlate=5;
    neckRadius=4;
    slotThickness=4;
    slotBacking=2;
    slotTolerance=-1;
    
    blockWidth=2;
    blockHeight=2;
    
    motorThickness=15;
    motorHeight=30+blockHeight;
    motorNeckLength=8;
    
    supportWidth=1.25;
    
    bottomLength=motorThickness/2+bigRadius+clearance+addendum;
    blockLength=bottomLength+slotBacking-lockPlate-slotTolerance;
    
    blockLocation=motorHeight-blockHeight+wallThickness;
    
    
    
    
    translate([0, 0, motorNeckLength-wallThickness])
    {
      union()
      { 
        difference()
        {
          union()
          {
            cube([bottomLength, width, wallThickness]);
            difference()
            {
              translate([lockPlate, 0, 0]) cube([blockLength, width, motorHeight+wallThickness]);
              translate([lockPlate, width/2-motorWidth/2, layerHeight])
              {
                cube([blockLength, motorWidth, motorHeight+wallThickness]);
              }
            }
            translate([blockLength+lockPlate-supportWidth, 0, -layerHeight])
            {
              cube([supportWidth, width, layerHeight]);
            }
          }
          translate([bottomLength-bigRadius, width/2, layerHeight]) cylinder(r=neckRadius, h=wallThickness);
          translate([bottomLength-bigRadius, width/2-neckRadius, layerHeight])
          {
            cube([bottomLength, 2*neckRadius, wallThickness]);
          }
          translate([bottomLength-slotTolerance, 0, wallThickness]) rotate([0, -90, 0])
          {
            cube([motorHeight, width, slotThickness]);
          }
        }
        
        difference()
        {
          translate([bottomLength-blockWidth-slotTolerance, 0, blockLocation])
          {
            cube([blockWidth, width, blockHeight]);
          }
          translate([bottomLength-blockWidth-slotTolerance, (width-motorWidth)/2, blockLocation+layerHeight])
          {
            cube([blockWidth, motorWidth, blockHeight]);
          }
        }
      }
    }
  }
}
caseAssembled();


