include <gearLibrary.scad>;

$fn=200;

module outputGear()
{
    wallThickness=2.4;
    
    bottomHeight=3.4;
    topHeight=7.0;
    
    smallGearTeeth=6;
    smallGearPitch=5.5;
    
    gearTeeth=12;
    topGearPitch=16.5/2;
    bottomGearPitch=11;
    pressureAngle=15;
    
  outputRadius=4;
  
    shaftHeight=16;
    tiltAngle=30;
    shaftRadius=5.5;
    tiltHeight=(shaftRadius-outputRadius)*tan(90-tiltAngle);
    
    
    slotDepth=2.6;
    slotWidth=2.6;
    
    outputHeight=wallThickness+12;
    
    axleRadius=2.5;
    axleHeight=16;
    
    addendumTolerance=1.0;
    dedendumTolerance=0.5;
    
    addendum0=addendumCalc(bottomGearPitch, pressureAngle, gearTeeth, smallGearTeeth);
    dedendum0=addendumCalc(smallGearPitch, pressureAngle, smallGearTeeth, gearTeeth)+addendumTolerance;
    
    addendum1=addendumCalc(topGearPitch, pressureAngle, gearTeeth, gearTeeth)+addendumTolerance-dedendumTolerance;
    
    difference()
    {
        union()
        {
            gear(bottomGearPitch, pressureAngle, gearTeeth, addendum0, dedendum0+dedendumTolerance, bottomHeight, 0, 0.2);
            
            translate([0, 0, bottomHeight])
            {
                gear(topGearPitch, pressureAngle, gearTeeth, addendum1, addendum1+dedendumTolerance, topHeight, 0, 0.2);
            }
            
            translate([0, 0, bottomHeight+topHeight])
            {
                cylinder(r=shaftRadius, h=shaftHeight-tiltHeight);
            }
            
            translate([0, 0, bottomHeight+topHeight+shaftHeight-tiltHeight])
            {
              cylinder(r1=shaftRadius, r2=outputRadius, h=tiltHeight);
            }
            
            translate([0, 0, bottomHeight+topHeight+shaftHeight])
            {
                rotate([0, 0, 360/24])
                {
                    output(outputRadius, outputHeight, slotDepth, slotWidth);
                }
            }
        }
        
        cylinder(r=axleRadius, h=axleHeight);
    }
}

module output(outputRadius, outputHeight, slotDepth, slotWidth)
{
    difference()
    {
        cylinder(r=outputRadius, h=outputHeight);
        
        translate([outputRadius-slotDepth, 0, outputHeight-1.5*slotWidth])
        {
            rotate([0, -45, 0])
            {
                translate([0, -outputRadius, -slotDepth/(sqrt(2))])
                {
                    cube([slotDepth*sqrt(2), 2*outputRadius, slotDepth/sqrt(2)]);
                }
            }
        }
        
        translate([outputRadius-slotDepth, -outputRadius, outputHeight-2.5*slotWidth])
        {
            cube([slotDepth, 2*outputRadius, slotWidth]);
        }
        
        translate([outputRadius-slotDepth, -slotWidth/2, outputHeight-2.5*slotWidth])
        {
            cube([slotDepth, slotWidth, 2.5*slotWidth]);
        }
    }
}

outputGear();
