include <gearLibrary.scad>

$fn=100;

module sensorGear()
{
    gearPitch=16.5/2;
    teethNumber=12;
    pressureAngle=12;
    gearThickness=4;
    addendum=addendumCalc(gearPitch, pressureAngle, teethNumber, teethNumber)+0.8;
    dedendum=addendum+0.3;//gearPitch-6;
    
    innerRadius=2.0;
    
    rodTolerance=0.5;
    
    rodRadius=2.8/2;
    boxDistance=5.8;
    boxHeight=6;
    slopeBox=boxHeight/boxDistance;
    slopeRod=rodRadius/sqrt(pow(boxHeight, 2)+pow(boxDistance, 2)-pow(rodRadius, 2));
    rodAngle=atan((1-slopeBox*slopeRod)/(slopeBox+slopeRod));
    rodLength=2*(boxHeight/sin(rodAngle)+rodRadius*tan(rodAngle));
  
    collarHeight=3;
    collarRadius=6.2;
    
    
    
    barThickness=0.8;
    shapeRadius=3.2;
    shapeThickness=0.8;//0.8 before
    gearShellThickness=1.3;
    angularTolerance=25;
    
    shellRadius=collarRadius-gearShellThickness;//gearPitch-dedendum-gearShellThickness;
    
    
    echo(rodAngle);
    echo(1+slopeRod);
    echo(slopeBox);
    
    union()
    {
        difference()
        {
            union()
            {
              gear(gearPitch, pressureAngle, teethNumber, addendum, dedendum, gearThickness, 0, 0.1);
              cylinder(r=collarRadius, h=gearThickness+collarHeight);
            }
            
            cylinder(r=shellRadius, h=gearThickness+collarHeight+0.1);
        }
        
        translate([0, 0, collarHeight])
        {
          intersection()
          {
              translate([-boxDistance, 0, gearThickness])
              {
                  rotate([0, rodAngle, 0])
                  {
                      translate([rodRadius, 0, -5])
                      {
                          cylinder(r=rodRadius, h=rodLength+5);
                      }
                  }
              }
              
              union()
              {
                  //gear(gearPitch, pressureAngle, teethNumber, addendum, dedendum, gearThickness+2*boxHeight, 0, 0.1);
                  cylinder(r=6, h=gearThickness+2*boxHeight-rodTolerance);
                
                  translate([0, -(gearPitch+addendum), 0])
                  {
                      cube([boxDistance, 2*(gearPitch+addendum), gearThickness+2*boxHeight-rodTolerance]);
                  }
              }
          }
        }
        
        for(i=[0:2])
        {
            rotate([0, 0, i*360/3-90/3])
            {
                contactPiece(innerRadius, shapeRadius, gearThickness, shapeThickness, barThickness, angularTolerance, shellRadius);
            }
        }
    }
}

module contactPiece(innerRadius, shapeRadius, height, shapeThickness, barThickness, angularTolerance, shellRadius)
{
    translateDistance=shapeRadius-innerRadius;
    angularWidth=360/3-2*angularTolerance;
    
    shapeOuterRadius=shapeRadius+shapeThickness;
    
    xPoint=shapeOuterRadius*tan(angularWidth/2);
    
    tolerance=0.2;
    
    translate([0, -translateDistance, 0])
    {
        difference()
        {
            union()
            {
                intersection()
                {
                    translate([0, shapeOuterRadius-barThickness, 0])
                    {
                        cube([shellRadius, barThickness, height]);
                    }
                    
                    translate([0, translateDistance, 0])
                    {
                        cylinder(r=shellRadius+tolerance, h=height);
                    }
                }
                
                intersection()
                {
                    cylinder(r=shapeOuterRadius, h=height);
                    
                    linear_extrude(height=height)
                    {
                        polygon(points=[[0, 0,], [xPoint, shapeOuterRadius], [-xPoint, shapeOuterRadius]]);
                    }
                }
            }
            
            cylinder(r=shapeRadius, h=height);
        }
    }
}

sensorGear();